'use strict';

angular.module('adf.widget.electre.lavoisier', ['adf.provider', 'ngTable'])
    .constant('CONTROLLER_TYPE', {
        html   : "html",
        iFrame : "iFrame",
        table  : "table",
        text   : "text",
        chart  : "chart"
    }).constant('LAVOISIER_TEMPLATES_PATH', '/resource/rsc/electre/widgets/lavoisier/templates')
    .config(
        [
            "dashboardProvider", "CONTROLLER_TYPE",
            function (dashboardProvider, CONTROLLER_TYPE) {
                var widget = {
                    reload : true,
                    resolve : {
                        baseController : [
                            "$controller",
                            function ($controller) {
                                $controller("baseLavoisierController", {$scope : this});
                                return this;
                            }
                        ]
                    },
                    edit   : {
                        controller  : 'lavoisierGeneriqueEditCtrl',
                        immediate   : true,
                        templateUrl : '{widgetsPath}/lavoisier/templates/edit/edit.html'
                    }
                };

                dashboardProvider
                .widget('lavoisierHtml',
                    angular.extend({
                        title       : 'Lavoisier html widget',
                        display     : 'Lavoisier html widget for dashboard electre.',
                        description : "Embed HTML content from lavoisier source (Rendering = HTML).",
                        controller  : 'lavoisierHtmlCtrl',
                        controllerAs: 'lavoisierHtml',
                        templateUrl : '{widgetsPath}/lavoisier/templates/widgets/html/view.html',
                        config      : {
                            type: CONTROLLER_TYPE.html
                        }
                    }, widget)
                ).widget('lavoisierIFrame',
                    angular.extend({
                        title       : 'Lavoisier iframe widget',
                        display     : 'Lavoisier iframe widget for dashboard electre.',
                        description : "Display a iframe with a lavoisier url for source (Rendering = CHART|GZ|HTML|PDF|XLSX.XML|ZIP).",
                        controller  : 'lavoisierIframeCtrl',
                        controllerAs: 'lavoisierIframe',
                        templateUrl : '{widgetsPath}/lavoisier/templates/widgets/iframe/view.html',
                        config      : {
                            type: CONTROLLER_TYPE.iFrame
                        }
                    }, widget)
                ).widget('lavoisierTable',
                    angular.extend({
                        title       : 'Lavoisier table widget',
                        display     : 'Lavoisier table widget for dashboard electre.',
                        description : "Create table from lavoisier (Rendering = ROWCOL).",
                        controller  : 'lavoisierTableCtrl',
                        controllerAs: 'lavoisierTable',
                        templateUrl : '{widgetsPath}/lavoisier/templates/widgets/table/view.html',
                        config      : {
                            type: CONTROLLER_TYPE.table
                        }
                    }, widget)
                ).widget('lavoisierText',
                    angular.extend({
                        title       : 'Lavoisier text widget',
                        display     : 'Lavoisier text widget for dashboard electre.',
                        description : "Display the view as text (Rendering = TXT|CSV|JSON|JSON2|JSONML|LDIF|SQL|XML).",
                        controller  : 'lavoisierTextCtrl',
                        controllerAs: 'lavoisierText',
                        templateUrl : '{widgetsPath}/lavoisier/templates/widgets/text/view.html',
                        config      : {
                            type: CONTROLLER_TYPE.text
                        }
                    }, widget)
                ).widget('lavoisierChart',
                    angular.extend({
                        title       : 'Lavoisier chart widget',
                        display     : 'Lavoisier chart widget for dashboard electre.',
                        description : "Display a chart from lavoisier (Rendering = ROWCOL).",
                        controller  : 'lavoisierChartCtrl',
                        controllerAs: 'lavoisierChart',
                        templateUrl : '{widgetsPath}/lavoisier/templates/widgets/chart/view.html',
                        config      : {
                            type: CONTROLLER_TYPE.chart
                        }
                    }, widget)
                );
            }
        ]
    )
;